package at.xaxa.ledger.ui.category.edit

import android.util.Log
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.ExposedDropdownMenuDefaults.TrailingIcon
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.data.Entry
import at.xaxa.ledger.data.db.Category.CategoryEntity
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonDanger
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.DatePickerDocked
import at.xaxa.ledger.ui.category.CategoryViewModel
import at.xaxa.ledger.ui.category.iconNames
import at.xaxa.ledger.ui.category.icons
import at.xaxa.ledger.ui.edit.EditViewModel



@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun EditCategory(
    onButtonClick: () -> Unit,
    modifier: Modifier = Modifier,
    editCategoryViewModel: EditCategoryViewModel = viewModel(factory = AppViewModelProvider.Factory)
) {

    var expanded by remember { mutableStateOf(false) } // Controls dropdown visibility
    val category = editCategoryViewModel.categoryUi.category
    var selectedIconIndex = category.icon // Store index of selected icon

    Log.d(
        "kkjkjkjkj",
        category.categoryName)


    /*
    val categories by categoryViewModel.categoryUiState.categories.collectAsState(initial = emptyList())
    val category = categoryViewModel.categoryUi.category
    var expanded by remember { mutableStateOf(false) }*/

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        OutlinedTextField(
            value = category.categoryName,
            onValueChange = { editCategoryViewModel.updateCategory(category.copy(categoryName = it)) },
            label = { Text("Category Name") },
            modifier = Modifier
                .fillMaxWidth()
        )

        ExposedDropdownMenuBox(
            expanded = expanded,
            onExpandedChange = { expanded = it }
        ) {
            OutlinedTextField(
                value = iconNames[selectedIconIndex], // Show selected icon name
                onValueChange = {},
                label = { Text("Icon") },
                readOnly = true,
                leadingIcon = {
                    Icon(
                        imageVector = icons[selectedIconIndex], // Replace with your desired icon
                        contentDescription = "Leading Icon"
                    )
                },
                trailingIcon = {
                    ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded)
                },
                modifier = Modifier
                    .menuAnchor()
                    .fillMaxWidth()
            )

            ExposedDropdownMenu(
                expanded = expanded,
                onDismissRequest = { expanded = false }
            ) {
                icons.forEachIndexed { index, icon ->
                    DropdownMenuItem(
                        text = { Text(text = iconNames[index]) }, // Use name from iconNames
                        onClick = {
                            selectedIconIndex = index // Update selected index

                            category.copy(_id = index)
                            editCategoryViewModel.updateCategory(category)
                            expanded = false
                        },
                        leadingIcon = {
                            androidx.compose.material3.Icon(
                                imageVector = icon,
                                contentDescription = iconNames[index]
                            )
                        }
                    )
                }
            }
        }

        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(
                modifier = Modifier,
                "Edit Category",
                onClick = {
                    editCategoryViewModel.saveCategory()
                    onButtonClick()
                }
            )
        }
    }
}

