package at.xaxa.ledger.ui.category.edit

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import at.xaxa.ledger.data.Entry
import at.xaxa.ledger.data.EntryRepository
import at.xaxa.ledger.data.db.Category.CategoryEntity
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flowOf
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

data class CategoryUIState(val category: CategoryEntity = CategoryEntity(0,"",0))



class EditCategoryViewModel(private val savedStateHandle: SavedStateHandle,
                            private val entryRepository: EntryRepository
) : ViewModel() {


    private val categoryId: Int = checkNotNull(savedStateHandle["categoryId"])


    var categoryUiState by mutableStateOf(CategoryUIState())
    var categoryUi by mutableStateOf(CategoryUIState())
        private set


    init {
        viewModelScope.launch {
            val category = withContext(Dispatchers.IO) {
                entryRepository.findCategoryById(categoryId)
            }
            categoryUi = CategoryUIState(category)
        }
    }

    fun updateCategory(category: CategoryEntity) {
        categoryUi = categoryUi.copy(category = category)
    }
    fun onDeleteEntry(category: CategoryEntity) {
        viewModelScope.launch {
            entryRepository.deleteCategory(category)
        }
    }
    fun saveCategory() {
        viewModelScope.launch {
            entryRepository.updateCategory(categoryUi.category)
        }
    }

    fun findCategoryByID(categoryId: Int) {
        viewModelScope.launch {
            val category = withContext(Dispatchers.IO) {
                entryRepository.findCategoryById(categoryId)
            }
            categoryUi = CategoryUIState(category)
        }
    }
}
